expand_refs

Function expand_refs 

pub fn expand_refs(
    asset: &str,
    coin: impl IntoCoins,
    month: impl IntoMonths,
) -> Result<Vec<PartitionRef>, TesseraError>
Expand (asset, coins, months) into the cartesian list of partitions.

Coin-major ordering: every month of the first coin, then the second, …

Errors

Returns TesseraError::InvalidArgument when either argument is empty or contains an invalid month.